local mapMod = foundation.createMod();

mapMod:registerAssetId("maps/heightmap.png", "HEIGHT_MAP")
mapMod:registerAssetId("maps/material_mask.png", "MATERIAL_MASK")
mapMod:registerAssetId("maps/coniferous_density.png", "CONIFEROUS_DENSITY_MAP")
mapMod:registerAssetId("maps/deciduous_density.png", "DECIDUOUS_DENSITY_MAP")
mapMod:registerAssetId("maps/berries_density.png", "BERRIES_DENSITY_MAP")
mapMod:registerAssetId("maps/rocks_density.png", "ROCKS_DENSITY_MAP")
mapMod:registerAssetId("maps/iron_density.png", "IRON_DENSITY_MAP")
mapMod:registerAssetId("maps/fish_density.png", "FISH_DENSITY_MAP")

mapMod:register({
	DataType = "CUSTOM_MAP",
	Id = "MAP_TWISTYRIVER",
	HeightMap = "HEIGHT_MAP",
	MaterialMask = "MATERIAL_MASK",
	MinHeight = -5,
	MaxHeight = 150,
	VillagePathList = {
		{
			Entrance = { 10, 0, 520 },
			Exit = { 10, 0, 520 }
		},
		{
			Entrance = { 10, 0, 623 },
			Exit = { 10, 0, 623 }
		},
		{
			Entrance = { 1010, 0, 542 },
			Exit = { 1010, 0, 542 }
		},
		{
			Entrance = { 1010, 0, 367 },
			Exit = { 1010, 0, 367 }
		},

	},
	
	
	DensitySpawnList = {
		{
			-- Create forest of Deciduous trees and a few smaller Pine trees
			DensityMap = "DECIDUOUS_DENSITY_MAP",
			Density = 0.5,
			PrefabConfigList = {
				{
					PrefabList = { "PREFAB_TREE_SYCAMORE", "PREFAB_TREE_OAK", "PREFAB_TREE_POPLAR" },
					RandomWeight = 1,
					OffsetSizeRange = {
						Min = 0.75,
						Max = 1.0
					},
					OrientationRange = {
						Min = { 0, -180, 0},
						Max = { 0, 180, 0}
					},
					ScaleRange = {
						Min = 1.0,
						Max = 1.5
					},
					ColorRange = {
						--Min = { 0.8, 0.8, 0.8, 1 },
						--Max = { 1, 1, 1, 1 }
						Min = { 0.7, 0.7, 0.7, 1 },
						Max = { 0.75, 0.75, 0.75, 1 }
					}
				},
				{
					PrefabList = { "PREFAB_TREE_PINE" },
					RandomWeight = 0.01,
					OffsetSizeRange = {
						Min = 0.5,
						Max = 0.9
					},
					OrientationRange = {
						Min = { 0, -180, 0},
						Max = { 0, 180, 0}
					},
					ScaleRange = {
						Min = 0.7,
						Max = 1.5
					},
					ColorRange = {
						Min = { 0.6, 0.6, 0.6, 1 },
						Max = { 0.6, 0.6, 0.6, 1}
					}
				}
			}
		},
		
		
		{
			-- Create forest of Pine trees
			DensityMap = "CONIFEROUS_DENSITY_MAP",
			Density = 0.5,
			PrefabConfigList = {
				{
					PrefabList = { "PREFAB_TREE_PINE" },
					RandomWeight = 0.1,
					OffsetSizeRange = {
						Min = 0.75,
						Max = 1
					},
					OrientationRange = {
						Min = { 0, -180, 0},
						Max = { 0, 180, 0}
					},
					ScaleRange = {
						Min = 0.95,
						Max = 2.0
					},
					ColorRange = {
						Min = { 0.5, 0.5, 0.5, 1 },
						Max = { 0.55, 0.55, 0.55, 1 }
					}
				}
			}
		},
		{
		-- Create berries resources containers
			DensityMap = "BERRIES_DENSITY_MAP",
			Density = 1,
			PrefabConfigList = {
				{
					PrefabList = { "PREFAB_RESOURCE_BERRIES" },
					RandomWeight = 0,
					OffsetSizeRange = {
						Min = 1,
						Max = 1
					},
					OrientationRange = {
						Min = { 0.0, -180, 0.0},
						Max = { 0.0, 180, 0.0}
					},
					ScaleRange = {
						Min = 1,
						Max = 1
					},
					ColorRange = {
						Min = { 0.8, 0.8, 0.8, 1 },
						Max = { 1, 1, 1, 1 }
					}
				}
			}
		},
		{
		-- Create rocks resources containers
			DensityMap = "ROCKS_DENSITY_MAP",
			Density = 1,
			PrefabConfigList = {
				{
					PrefabList = { "PREFAB_RESOURCE_ROCK" },
					RandomWeight = 0,
					OffsetSizeRange = {
						Min = 1,
						Max = 1
					},
					OrientationRange = {
						Min = { 0.0, -180, 0.0},
						Max = { 0.0, 180, 0.0}
					},
					ScaleRange = {
						Min = 1,
						Max = 1
					},
					ColorRange = {
						Min = { 0.8, 0.8, 0.8, 1 },
						Max = { 1, 1, 1, 1 }
					}
				}
			}
		},
		
        {
                -- Create fish shoals
                DensityMap = "FISH_DENSITY_MAP",
                Density = 1,
                PrefabConfigList = {
                {
                    PrefabList = { "PREFAB_RESOURCE_FISH" },
                    RandomWeight = 0.1,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1
                    },
                    OrientationRange = {
                        Min = { 0, -180, 0},
                        Max = { 0, 180, 0}
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                    ColorRange = {
                        Min = { 0.8, 0.8, 0.8, 1 },
                        Max = { 1, 1, 1, 1 }
                    }
                }
            }
	},
	
	{
                -- Create iron
                DensityMap = "IRON_DENSITY_MAP",
                Density = 1,
                PrefabConfigList = {
                {
                    PrefabList = { "PREFAB_RESOURCE_IRON" },
                    RandomWeight = 0.1,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1
                    },
                    OrientationRange = {
                        Min = { 0, -180, 0},
                        Max = { 0, 180, 0}
                    },
                    ScaleRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                    ColorRange = {
                        Min = { 0.8, 0.8, 0.8, 1 },
                        Max = { 1, 1, 1, 1 }
                    }
                }
            }
	}
}
})